<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance.salary');

// 记录访问日志
record_log('访问工资管理页面');

// 添加/编辑工资记录处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加工资记录
    if ($_POST['action'] == 'add') {
        $emp_id = isset($_POST['emp_id']) ? intval($_POST['emp_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $salary_month = isset($_POST['salary_month']) ? trim($_POST['salary_month']) : '';
        $base_salary = isset($_POST['base_salary']) ? floatval($_POST['base_salary']) : 0;
        $commission = isset($_POST['commission']) ? floatval($_POST['commission']) : 0;
        $bonus = isset($_POST['bonus']) ? floatval($_POST['bonus']) : 0;
        $deduction = isset($_POST['deduction']) ? floatval($_POST['deduction']) : 0;

        // 计算实发工资
        $total_salary = $base_salary + $commission + $bonus - $deduction;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($emp_id <= 0 || $store_id <= 0 || empty($salary_month) || $base_salary < 0) {
            $error = '请填写完整工资信息！';
        } else {
            try {
                // 检查该员工该月份是否已有工资记录
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_salary WHERE emp_id = ? AND salary_month = ?");
                $stmt->execute([$emp_id, $salary_month]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该员工本月已有工资记录！';
                } else {
                    // 添加工资记录
                    $stmt = $pdo->prepare("INSERT INTO fin_salary (emp_id, store_id, salary_month, base_salary, commission, bonus, deduction, total_salary, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$emp_id, $store_id, $salary_month, $base_salary, $commission, $bonus, $deduction, $total_salary, $status]);

                    if ($result) {
                        // 获取员工姓名，用于日志记录
                        $stmt = $pdo->prepare("SELECT name FROM emp_info WHERE id = ?");
                        $stmt->execute([$emp_id]);
                        $emp = $stmt->fetch();
                        $emp_name = $emp ? $emp['name'] : '未知员工';

                        record_log("添加工资记录：{$emp_name}，{$salary_month}，实发工资：{$total_salary}元");
                        $success = '工资记录添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: salary.php?success=add');
                        exit;
                    } else {
                        $error = '工资记录添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑工资记录
    elseif ($_POST['action'] == 'edit') {
        $salary_id = isset($_POST['salary_id']) ? intval($_POST['salary_id']) : 0;
        $emp_id = isset($_POST['emp_id']) ? intval($_POST['emp_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $salary_month = isset($_POST['salary_month']) ? trim($_POST['salary_month']) : '';
        $base_salary = isset($_POST['base_salary']) ? floatval($_POST['base_salary']) : 0;
        $commission = isset($_POST['commission']) ? floatval($_POST['commission']) : 0;
        $bonus = isset($_POST['bonus']) ? floatval($_POST['bonus']) : 0;
        $deduction = isset($_POST['deduction']) ? floatval($_POST['deduction']) : 0;

        // 计算实发工资
        $total_salary = $base_salary + $commission + $bonus - $deduction;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($salary_id <= 0 || $emp_id <= 0 || $store_id <= 0 || empty($salary_month) || $base_salary < 0) {
            $error = '请填写完整工资信息！';
        } else {
            try {
                // 检查该员工该月份是否已有其他工资记录
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_salary WHERE emp_id = ? AND salary_month = ? AND id != ?");
                $stmt->execute([$emp_id, $salary_month, $salary_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该员工本月已有其他工资记录！';
                } else {
                    // 更新工资信息
                    $payment_time = ($status == 2) ? 'NOW()' : 'NULL';
                    $stmt = $pdo->prepare("UPDATE fin_salary SET emp_id = ?, store_id = ?, salary_month = ?, base_salary = ?, commission = ?, bonus = ?, deduction = ?, total_salary = ?, status = ?, payment_time = " . ($status == 2 ? 'NOW()' : 'NULL') . " WHERE id = ?");
                    $result = $stmt->execute([$emp_id, $store_id, $salary_month, $base_salary, $commission, $bonus, $deduction, $total_salary, $status, $salary_id]);

                    if ($result) {
                        // 获取员工姓名，用于日志记录
                        $stmt = $pdo->prepare("SELECT name FROM emp_info WHERE id = ?");
                        $stmt->execute([$emp_id]);
                        $emp = $stmt->fetch();
                        $emp_name = $emp ? $emp['name'] : '未知员工';

                        record_log("编辑工资记录：{$emp_name}，{$salary_month}，实发工资：{$total_salary}元");
                        $success = '工资记录更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: salary.php?success=edit');
                        exit;
                    } else {
                        $error = '工资记录更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除工资记录
    elseif ($_POST['action'] == 'delete') {
        $salary_id = isset($_POST['salary_id']) ? intval($_POST['salary_id']) : 0;

        if ($salary_id <= 0) {
            $error = '无效的工资记录ID！';
        } else {
            try {
                // 获取工资记录信息，用于日志记录
                $stmt = $pdo->prepare("
                    SELECT s.*, e.name as emp_name 
                    FROM fin_salary s
                    LEFT JOIN emp_info e ON s.emp_id = e.id
                    WHERE s.id = ?
                ");
                $stmt->execute([$salary_id]);
                $salary = $stmt->fetch();

                if (!$salary) {
                    $error = '工资记录不存在！';
                } else {
                    // 删除工资记录
                    $stmt = $pdo->prepare("DELETE FROM fin_salary WHERE id = ?");
                    $result = $stmt->execute([$salary_id]);

                    if ($result) {
                        record_log("删除工资记录：{$salary['emp_name']}，{$salary['salary_month']}，实发工资：{$salary['total_salary']}元");
                        $success = '工资记录删除成功！';
                    } else {
                        $error = '工资记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 工资发放操作
    elseif ($_POST['action'] == 'pay') {
        $salary_id = isset($_POST['salary_id']) ? intval($_POST['salary_id']) : 0;

        if ($salary_id <= 0) {
            $error = '无效的工资记录ID！';
        } else {
            try {
                // 获取工资记录信息，用于日志记录
                $stmt = $pdo->prepare("
                    SELECT s.*, e.name as emp_name 
                    FROM fin_salary s
                    LEFT JOIN emp_info e ON s.emp_id = e.id
                    WHERE s.id = ?
                ");
                $stmt->execute([$salary_id]);
                $salary = $stmt->fetch();

                if (!$salary) {
                    $error = '工资记录不存在！';
                } elseif ($salary['status'] == 2) {
                    $error = '该工资已发放，不能重复发放！';
                } else {
                    // 更新工资状态
                    $stmt = $pdo->prepare("UPDATE fin_salary SET status = 2, payment_time = NOW() WHERE id = ?");
                    $result = $stmt->execute([$salary_id]);

                    if ($result) {
                        record_log("发放工资：{$salary['emp_name']}，{$salary['salary_month']}，实发工资：{$salary['total_salary']}元");
                        $success = '工资发放成功！';
                    } else {
                        $error = '工资发放失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_emp_id = isset($_GET['emp_id']) ? intval($_GET['emp_id']) : 0;
$filter_month = isset($_GET['month']) ? trim($_GET['month']) : '';
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有员工信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, name, store_id FROM emp_info WHERE status = 1 ORDER BY store_id, name");
    $employees = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取员工信息失败：' . $e->getMessage();
    $employees = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "s.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_emp_id > 0) {
    $where[] = "s.emp_id = ?";
    $params[] = $filter_emp_id;
}

if (!empty($filter_month)) {
    $where[] = "s.salary_month = ?";
    $params[] = $filter_month;
}

if ($filter_status > 0) {
    $where[] = "s.status = ?";
    $params[] = $filter_status;
}

// 获取工资记录数据
try {
    $sql = "
        SELECT s.*, e.name as emp_name, st.store_name 
        FROM fin_salary s
        LEFT JOIN emp_info e ON s.emp_id = e.id
        LEFT JOIN store_info st ON s.store_id = st.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY s.salary_month DESC, s.store_id, s.emp_id";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $salaries = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取工资记录失败：' . $e->getMessage();
    $salaries = [];
}

// 计算薪资统计数据
$total_records = count($salaries);
$total_base_salary = 0;
$total_commission = 0;
$total_bonus = 0;
$total_deduction = 0;
$total_salary = 0;
$paid_count = 0;

foreach ($salaries as $salary) {
    $total_base_salary += $salary['base_salary'];
    $total_commission += $salary['commission'];
    $total_bonus += $salary['bonus'];
    $total_deduction += $salary['deduction'];
    $total_salary += $salary['total_salary'];
    if ($salary['status'] == 2) {
        $paid_count++;
    }
}

// 判断是否显示表单
$show_form = false;
$edit_salary = null;

// 编辑工资记录时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM fin_salary WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_salary = $stmt->fetch();
        if (!$edit_salary) {
            $error = '工资记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取工资记录信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加工资记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '工资记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '工资记录更新成功！';
    }
}

// 获取可选的月份列表（从最近12个月）
$months = [];
for ($i = 0; $i < 12; $i++) {
    $month = date('Y-m', strtotime("-$i month"));
    $months[] = $month;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>工资管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 工资管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="salary.php?action=add" class="btn btn-add">添加工资记录</a>
            </div>

            <!-- 添加/编辑工资记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_salary ? '编辑工资记录' : '添加工资记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_salary ? 'edit' : 'add'; ?>">
                        <?php if ($edit_salary): ?>
                            <input type="hidden" name="salary_id" value="<?php echo $edit_salary['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">请选择门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($edit_salary && $edit_salary['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="emp_id">员工姓名：</label>
                            <select id="emp_id" name="emp_id" required>
                                <option value="">请选择员工</option>
                                <?php foreach ($employees as $emp): ?>
                                    <option value="<?php echo $emp['id']; ?>" <?php echo ($edit_salary && $edit_salary['emp_id'] == $emp['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($emp['name']); ?> (门店ID:<?php echo $emp['store_id']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="salary_month">工资月份：</label>
                            <select id="salary_month" name="salary_month" required>
                                <option value="">请选择月份</option>
                                <?php foreach ($months as $month): ?>
                                    <option value="<?php echo $month; ?>" <?php echo ($edit_salary && $edit_salary['salary_month'] == $month) ? 'selected' : ''; ?>>
                                        <?php echo $month; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="base_salary">基本工资：</label>
                            <input type="number" id="base_salary" name="base_salary" step="0.01" min="0" value="<?php echo $edit_salary ? htmlspecialchars($edit_salary['base_salary']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="commission">提成：</label>
                            <input type="number" id="commission" name="commission" step="0.01" min="0" value="<?php echo $edit_salary ? htmlspecialchars($edit_salary['commission']) : '0.00'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="bonus">奖金：</label>
                            <input type="number" id="bonus" name="bonus" step="0.01" min="0" value="<?php echo $edit_salary ? htmlspecialchars($edit_salary['bonus']) : '0.00'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="deduction">扣款：</label>
                            <input type="number" id="deduction" name="deduction" step="0.01" min="0" value="<?php echo $edit_salary ? htmlspecialchars($edit_salary['deduction']) : '0.00'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_salary && $edit_salary['status'] == 1) ? 'selected' : ''; ?>>未发放</option>
                                <option value="2" <?php echo ($edit_salary && $edit_salary['status'] == 2) ? 'selected' : ''; ?>>已发放</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="salary.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">所属门店：</label>
                                <select id="store_id" name="store_id">
                                    <option value="0">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="emp_id">员工姓名：</label>
                                <select id="emp_id" name="emp_id">
                                    <option value="0">全部员工</option>
                                    <?php foreach ($employees as $emp): ?>
                                        <option value="<?php echo $emp['id']; ?>" <?php echo ($filter_emp_id == $emp['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($emp['name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="month">工资月份：</label>
                                <select id="month" name="month">
                                    <option value="">全部月份</option>
                                    <?php foreach ($months as $month): ?>
                                        <option value="<?php echo $month; ?>" <?php echo ($filter_month == $month) ? 'selected' : ''; ?>>
                                            <?php echo $month; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="status">工资状态：</label>
                                <select id="status" name="status">
                                    <option value="0">全部状态</option>
                                    <option value="1" <?php echo ($filter_status == 1) ? 'selected' : ''; ?>>未发放</option>
                                    <option value="2" <?php echo ($filter_status == 2) ? 'selected' : ''; ?>>已发放</option>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="salary.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计摘要 -->
                <div class="info-box">
                    <h3>薪资统计摘要</h3>
                    <ul>
                        <li>记录总数：<?php echo $total_records; ?> 条</li>
                        <li>基本工资总额：￥<?php echo number_format($total_base_salary, 2); ?></li>
                        <li>提成总额：￥<?php echo number_format($total_commission, 2); ?></li>
                        <li>奖金总额：￥<?php echo number_format($total_bonus, 2); ?></li>
                        <li>扣款总额：￥<?php echo number_format($total_deduction, 2); ?></li>
                        <li>实发工资总额：￥<?php echo number_format($total_salary, 2); ?></li>
                        <li>已发放记录：<?php echo $paid_count; ?> 条</li>
                        <li>未发放记录：<?php echo $total_records - $paid_count; ?> 条</li>
                    </ul>
                </div>

                <!-- 工资记录列表 -->
                <div class="table-container">
                    <h3>工资记录列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店</th>
                                <th>员工姓名</th>
                                <th>工资月份</th>
                                <th>基本工资</th>
                                <th>提成</th>
                                <th>奖金</th>
                                <th>扣款</th>
                                <th>实发工资</th>
                                <th>状态</th>
                                <th>发放时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($salaries)): ?>
                                <tr>
                                    <td colspan="12" class="text-center">暂无工资记录数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($salaries as $salary): ?>
                                    <tr>
                                        <td><?php echo $salary['id']; ?></td>
                                        <td><?php echo htmlspecialchars($salary['store_name']); ?></td>
                                        <td><?php echo htmlspecialchars($salary['emp_name']); ?></td>
                                        <td><?php echo htmlspecialchars($salary['salary_month']); ?></td>
                                        <td>￥<?php echo number_format($salary['base_salary'], 2); ?></td>
                                        <td>￥<?php echo number_format($salary['commission'], 2); ?></td>
                                        <td>￥<?php echo number_format($salary['bonus'], 2); ?></td>
                                        <td>￥<?php echo number_format($salary['deduction'], 2); ?></td>
                                        <td>￥<?php echo number_format($salary['total_salary'], 2); ?></td>
                                        <td>
                                            <?php if ($salary['status'] == 1): ?>
                                                <span class="status-pending">未发放</span>
                                            <?php else: ?>
                                                <span class="status-active">已发放</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo $salary['payment_time'] ? date('Y-m-d H:i', strtotime($salary['payment_time'])) : '-'; ?></td>
                                        <td>
                                            <?php if ($salary['status'] == 1): ?>
                                                <a href="salary.php?action=edit&id=<?php echo $salary['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="pay">
                                                    <input type="hidden" name="salary_id" value="<?php echo $salary['id']; ?>">
                                                    <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定要发放该员工工资吗？');">发放</button>
                                                </form>
                                            <?php else: ?>
                                                <a href="salary.php?action=edit&id=<?php echo $salary['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <?php endif; ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="salary_id" value="<?php echo $salary['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该工资记录吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>