<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory.purchase');

// 记录访问日志
record_log('访问采购订单管理页面');

// 添加/编辑/处理采购订单
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加采购订单
    if ($_POST['action'] == 'add') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $material_id = isset($_POST['material_id']) ? intval($_POST['material_id']) : 0;
        $quantity = isset($_POST['quantity']) ? floatval($_POST['quantity']) : 0;
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;

        if ($supplier_id <= 0 || $material_id <= 0 || $quantity <= 0 || $price <= 0) {
            $error = '请填写完整采购信息！';
        } else {
            try {
                // 获取原料信息
                $stmt = $pdo->prepare("SELECT name, unit FROM inv_material WHERE id = ?");
                $stmt->execute([$material_id]);
                $material = $stmt->fetch();

                if (!$material) {
                    $error = '原料不存在！';
                } else {
                    // 生成采购单号
                    $order_no = 'PUR' . date('Ymd') . sprintf('%03d', rand(1, 999));

                    // 计算总金额
                    $amount = $quantity * $price;

                    // 添加采购订单
                    $stmt = $pdo->prepare("INSERT INTO pur_order (order_no, store_id, supplier_id, material_id, material_name, quantity, unit, price, amount, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, 1)");
                    $result = $stmt->execute([$order_no, $store_id, $supplier_id, $material_id, $material['name'], $quantity, $material['unit'], $price, $amount]);

                    if ($result) {
                        record_log("添加采购订单：{$order_no}，原料：{$material['name']}");
                        $success = '采购订单添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: purchase.php?success=add');
                        exit;
                    } else {
                        $error = '采购订单添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑采购订单
    elseif ($_POST['action'] == 'edit') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $quantity = isset($_POST['quantity']) ? floatval($_POST['quantity']) : 0;
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;

        if ($order_id <= 0 || $quantity <= 0 || $price <= 0) {
            $error = '请填写完整采购信息！';
        } else {
            try {
                // 检查订单状态
                $stmt = $pdo->prepare("SELECT status FROM pur_order WHERE id = ?");
                $stmt->execute([$order_id]);
                $order_status = $stmt->fetch();

                if (!$order_status) {
                    $error = '采购订单不存在！';
                } elseif ($order_status['status'] != 1) {
                    $error = '只能编辑待审核状态的采购订单！';
                } else {
                    // 计算总金额
                    $amount = $quantity * $price;

                    // 更新采购订单
                    $stmt = $pdo->prepare("UPDATE pur_order SET quantity = ?, price = ?, amount = ? WHERE id = ?");
                    $result = $stmt->execute([$quantity, $price, $amount, $order_id]);

                    if ($result) {
                        record_log("编辑采购订单ID：{$order_id}");
                        $success = '采购订单更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: purchase.php?success=edit');
                        exit;
                    } else {
                        $error = '采购订单更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 变更采购订单状态
    elseif ($_POST['action'] == 'status') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;

        if ($order_id <= 0 || !in_array($new_status, [2, 3, 4])) {
            $error = '无效的操作！';
        } else {
            try {
                // 检查订单状态
                $stmt = $pdo->prepare("SELECT * FROM pur_order WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if (!$order) {
                    $error = '采购订单不存在！';
                } elseif ($new_status == 2 && $order['status'] != 1) {
                    $error = '只能审核待审核状态的采购订单！';
                } elseif ($new_status == 3 && $order['status'] != 2) {
                    $error = '只能将已审核状态的订单标记为已入库！';
                } elseif ($new_status == 4 && $order['status'] == 3) {
                    $error = '已入库的订单不能取消！';
                } else {
                    // 更新订单状态
                    $stmt = $pdo->prepare("UPDATE pur_order SET status = ? WHERE id = ?");
                    $result = $stmt->execute([$new_status, $order_id]);

                    if ($result) {
                        $status_text = $new_status == 2 ? '已审核' : ($new_status == 3 ? '已入库' : '已取消');
                        record_log("更新采购订单ID：{$order_id}状态为：{$status_text}");

                        // 如果是入库操作，需要增加库存并记录
                        if ($new_status == 3) {
                            // 增加库存
                            $stmt = $pdo->prepare("UPDATE inv_material SET stock = stock + ? WHERE id = ? AND store_id = ?");
                            $stmt->execute([$order['quantity'], $order['material_id'], $order['store_id']]);

                            // 添加入库记录
                            $batch_no = 'B' . date('Ymd') . sprintf('%03d', rand(1, 999));
                            $expiry_date = date('Y-m-d', strtotime('+6 months'));

                            $stmt = $pdo->prepare("INSERT INTO inv_record (store_id, material_id, record_type, quantity, purchase_id, batch_no, expiry_date, operator) VALUES (?, ?, 1, ?, ?, ?, ?, ?)");
                            $stmt->execute([$order['store_id'], $order['material_id'], $order['quantity'], $order_id, $batch_no, $expiry_date, $_SESSION['username']]);
                        }

                        $success = '采购订单状态更新成功！';
                    } else {
                        $error = '采购订单状态更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除采购订单
    elseif ($_POST['action'] == 'delete') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($order_id <= 0) {
            $error = '无效的采购订单ID！';
        } else {
            try {
                // 检查订单状态
                $stmt = $pdo->prepare("SELECT status FROM pur_order WHERE id = ?");
                $stmt->execute([$order_id]);
                $order_status = $stmt->fetch();

                if (!$order_status) {
                    $error = '采购订单不存在！';
                } elseif ($order_status['status'] == 3) {
                    $error = '已入库的采购订单不能删除！';
                } else {
                    // 检查是否有关联的库存记录
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inv_record WHERE purchase_id = ?");
                    $stmt->execute([$order_id]);
                    $record_count = $stmt->fetch();

                    if ($record_count['count'] > 0) {
                        $error = '该采购订单已有库存记录，无法删除！';
                    } else {
                        // 删除采购订单
                        $stmt = $pdo->prepare("DELETE FROM pur_order WHERE id = ?");
                        $result = $stmt->execute([$order_id]);

                        if ($result) {
                            record_log("删除采购订单ID：{$order_id}");
                            $success = '采购订单删除成功！';
                        } else {
                            $error = '采购订单删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有门店
try {
    $stmt = $pdo->query("SELECT * FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有供应商
try {
    $stmt = $pdo->query("SELECT * FROM sup_info WHERE status = 1 ORDER BY id");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取供应商信息失败：' . $e->getMessage();
    $suppliers = [];
}

// 获取所有原料
try {
    $stmt = $pdo->query("SELECT * FROM inv_material WHERE status = 1 ORDER BY id");
    $materials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取原料信息失败：' . $e->getMessage();
    $materials = [];
}

// 获取所有采购订单，包含供应商名称和门店名称
try {
    $stmt = $pdo->query("
        SELECT p.*, s.name as supplier_name, st.store_name
        FROM pur_order p
        LEFT JOIN sup_info s ON p.supplier_id = s.id
        LEFT JOIN store_info st ON p.store_id = st.id
        ORDER BY p.id DESC
    ");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取采购订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 判断是否显示表单
$show_form = false;
$edit_order = null;

// 编辑采购订单时显示表单并获取订单信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM pur_order WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_order = $stmt->fetch();
        if (!$edit_order) {
            $error = '采购订单不存在！';
            $show_form = false;
        } elseif ($edit_order['status'] != 1) {
            $error = '只能编辑待审核状态的采购订单！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取采购订单信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加采购订单时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '采购订单添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '采购订单更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>采购订单管理</h2>
            <div class="breadcrumb">
                <a href="index.php">库存管理</a> &gt; 采购订单管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="purchase.php?action=add" class="btn btn-add">添加采购订单</a>
            </div>

            <!-- 添加/编辑采购订单表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_order ? '编辑采购订单' : '添加采购订单'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_order ? 'edit' : 'add'; ?>">
                        <?php if ($edit_order): ?>
                            <input type="hidden" name="order_id" value="<?php echo $edit_order['id']; ?>">
                        <?php endif; ?>

                        <?php if (!$edit_order): ?>
                            <div class="form-group">
                                <label for="store_id">所属门店：</label>
                                <select id="store_id" name="store_id">
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>">
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="supplier_id">供应商：</label>
                                <select id="supplier_id" name="supplier_id" required>
                                    <option value="">请选择供应商</option>
                                    <?php foreach ($suppliers as $supplier): ?>
                                        <option value="<?php echo $supplier['id']; ?>">
                                            <?php echo htmlspecialchars($supplier['name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="material_id">原料：</label>
                                <select id="material_id" name="material_id" required>
                                    <option value="">请选择原料</option>
                                    <?php foreach ($materials as $material): ?>
                                        <option value="<?php echo $material['id']; ?>">
                                            <?php echo htmlspecialchars($material['name']); ?> (<?php echo htmlspecialchars($material['unit']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php else: ?>
                            <div class="form-group">
                                <label>所属门店：</label>
                                <span><?php
                                        foreach ($stores as $store) {
                                            if ($store['id'] == $edit_order['store_id']) {
                                                echo htmlspecialchars($store['store_name']);
                                                break;
                                            }
                                        }
                                        ?></span>
                            </div>

                            <div class="form-group">
                                <label>供应商：</label>
                                <span><?php
                                        foreach ($suppliers as $supplier) {
                                            if ($supplier['id'] == $edit_order['supplier_id']) {
                                                echo htmlspecialchars($supplier['name']);
                                                break;
                                            }
                                        }
                                        ?></span>
                            </div>

                            <div class="form-group">
                                <label>原料：</label>
                                <span><?php echo htmlspecialchars($edit_order['material_name']); ?></span>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="quantity">数量：</label>
                            <input type="number" id="quantity" name="quantity" min="0.01" step="0.01" value="<?php echo $edit_order ? htmlspecialchars($edit_order['quantity']) : ''; ?>" required>
                            <?php if ($edit_order): ?>
                                <span><?php echo htmlspecialchars($edit_order['unit']); ?></span>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="price">单价：</label>
                            <input type="number" id="price" name="price" min="0.01" step="0.01" value="<?php echo $edit_order ? htmlspecialchars($edit_order['price']) : ''; ?>" required>
                            <span>元</span>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="purchase.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 采购订单列表 -->
            <div class="table-container">
                <h3>采购订单列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>采购单号</th>
                            <th>门店</th>
                            <th>供应商</th>
                            <th>原料名称</th>
                            <th>数量</th>
                            <th>单价</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($orders)): ?>
                            <tr>
                                <td colspan="11" class="text-center">暂无采购订单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?php echo $order['id']; ?></td>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($order['supplier_name']); ?></td>
                                    <td><?php echo htmlspecialchars($order['material_name']); ?></td>
                                    <td><?php echo number_format($order['quantity'], 2) . ' ' . htmlspecialchars($order['unit']); ?></td>
                                    <td><?php echo number_format($order['price'], 2); ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($order['status'] == 1) echo '<span class="status-pending">待审核</span>';
                                        elseif ($order['status'] == 2) echo '<span class="status-active">已审核</span>';
                                        elseif ($order['status'] == 3) echo '<span class="status-active">已入库</span>';
                                        else echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    <td>
                                        <?php if ($order['status'] == 1): ?>
                                            <a href="purchase.php?action=edit&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="status">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <input type="hidden" name="new_status" value="2">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定审核通过此采购订单吗？');">审核</button>
                                            </form>

                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="status">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <input type="hidden" name="new_status" value="4">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定取消此采购订单吗？');">取消</button>
                                            </form>

                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此采购订单吗？');">删除</button>
                                            </form>
                                        <?php elseif ($order['status'] == 2): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="status">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <input type="hidden" name="new_status" value="3">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确认已收到货物并入库吗？');">入库</button>
                                            </form>

                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="status">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <input type="hidden" name="new_status" value="4">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定取消此采购订单吗？');">取消</button>
                                            </form>
                                        <?php else: ?>
                                            <span class="btn btn-sm btn-secondary">无可用操作</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>