<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory.tracking');

// 记录访问日志
record_log('访问库存消耗追踪页面');

// 添加报废记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'waste') {
    $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
    $material_id = isset($_POST['material_id']) ? intval($_POST['material_id']) : 0;
    $quantity = isset($_POST['quantity']) ? floatval($_POST['quantity']) : 0;
    $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

    if ($material_id <= 0 || $quantity <= 0) {
        $error = '请填写完整报废信息！';
    } else {
        try {
            // 获取原料信息
            $stmt = $pdo->prepare("SELECT name, stock FROM inv_material WHERE id = ? AND store_id = ?");
            $stmt->execute([$material_id, $store_id]);
            $material = $stmt->fetch();

            if (!$material) {
                $error = '原料不存在！';
            } elseif ($material['stock'] < $quantity) {
                $error = '报废数量不能大于当前库存！';
            } else {
                // 开始事务
                $pdo->beginTransaction();

                // 添加报废记录
                $stmt = $pdo->prepare("INSERT INTO inv_record (store_id, material_id, record_type, quantity, operator, create_time) VALUES (?, ?, 3, ?, ?, NOW())");
                $stmt->execute([$store_id, $material_id, $quantity, $_SESSION['username']]);

                // 更新库存
                $stmt = $pdo->prepare("UPDATE inv_material SET stock = stock - ? WHERE id = ? AND store_id = ?");
                $stmt->execute([$quantity, $material_id, $store_id]);

                // 提交事务
                $pdo->commit();

                record_log("添加报废记录：{$material['name']}，数量：{$quantity}");
                $success = '报废记录添加成功！';

                // 重定向到没有参数的页面
                header('Location: tracking.php?success=waste');
                exit;
            }
        } catch (PDOException $e) {
            // 回滚事务
            $pdo->rollBack();
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 添加盘点调整记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'adjust') {
    $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
    $material_id = isset($_POST['material_id']) ? intval($_POST['material_id']) : 0;
    $quantity = isset($_POST['quantity']) ? floatval($_POST['quantity']) : 0;
    $adjustment_type = isset($_POST['adjustment_type']) ? intval($_POST['adjustment_type']) : 1; // 1:增加 2:减少
    $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

    if ($material_id <= 0 || $quantity <= 0) {
        $error = '请填写完整盘点信息！';
    } else {
        try {
            // 获取原料信息
            $stmt = $pdo->prepare("SELECT name, stock FROM inv_material WHERE id = ? AND store_id = ?");
            $stmt->execute([$material_id, $store_id]);
            $material = $stmt->fetch();

            if (!$material) {
                $error = '原料不存在！';
            } elseif ($adjustment_type == 2 && $material['stock'] < $quantity) {
                $error = '调整减少的数量不能大于当前库存！';
            } else {
                // 开始事务
                $pdo->beginTransaction();

                // 实际调整的数量（如果是减少，则为负数）
                $real_quantity = $adjustment_type == 1 ? $quantity : -$quantity;

                // 添加盘点调整记录
                $stmt = $pdo->prepare("INSERT INTO inv_record (store_id, material_id, record_type, quantity, operator, create_time) VALUES (?, ?, 4, ?, ?, NOW())");
                $stmt->execute([$store_id, $material_id, $real_quantity, $_SESSION['username']]);

                // 更新库存
                $stmt = $pdo->prepare("UPDATE inv_material SET stock = stock + ? WHERE id = ? AND store_id = ?");
                $stmt->execute([$real_quantity, $material_id, $store_id]);

                // 提交事务
                $pdo->commit();

                $action_text = $adjustment_type == 1 ? '增加' : '减少';
                record_log("盘点调整：{$material['name']}，{$action_text}数量：{$quantity}");
                $success = '盘点调整记录添加成功！';

                // 重定向到没有参数的页面
                header('Location: tracking.php?success=adjust');
                exit;
            }
        } catch (PDOException $e) {
            // 回滚事务
            $pdo->rollBack();
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 获取所有门店
try {
    $stmt = $pdo->query("SELECT * FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有原料
try {
    $stmt = $pdo->query("SELECT * FROM inv_material WHERE status = 1 ORDER BY id");
    $materials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取原料信息失败：' . $e->getMessage();
    $materials = [];
}

// 设置筛选条件
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_material_id = isset($_GET['material_id']) ? intval($_GET['material_id']) : 0;
$filter_record_type = isset($_GET['record_type']) ? intval($_GET['record_type']) : 0;
$filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 构建WHERE子句
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "r.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_material_id > 0) {
    $where[] = "r.material_id = ?";
    $params[] = $filter_material_id;
}

if ($filter_record_type > 0) {
    $where[] = "r.record_type = ?";
    $params[] = $filter_record_type;
}

if (!empty($filter_start_date)) {
    $where[] = "DATE(r.create_time) >= ?";
    $params[] = $filter_start_date;
}

if (!empty($filter_end_date)) {
    $where[] = "DATE(r.create_time) <= ?";
    $params[] = $filter_end_date;
}

$where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";

// 获取库存记录
try {
    $sql = "
        SELECT r.*, m.name as material_name, m.unit, s.store_name,
               CASE 
                   WHEN r.record_type = 1 THEN '入库'
                   WHEN r.record_type = 2 THEN '订单消耗'
                   WHEN r.record_type = 3 THEN '报废'
                   WHEN r.record_type = 4 THEN '盘点调整'
                   ELSE '未知'
               END as record_type_name,
               o.order_no, p.order_no as purchase_order_no
        FROM inv_record r
        LEFT JOIN inv_material m ON r.material_id = m.id
        LEFT JOIN store_info s ON r.store_id = s.id
        LEFT JOIN order_main o ON r.order_id = o.id
        LEFT JOIN pur_order p ON r.purchase_id = p.id
        $where_clause
        ORDER BY r.create_time DESC
        LIMIT 100
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $records = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存记录失败：' . $e->getMessage();
    $records = [];
}

// 获取库存消耗统计
try {
    $sql = "
        SELECT 
            m.name as material_name,
            m.unit,
            SUM(CASE WHEN r.record_type = 1 THEN r.quantity ELSE 0 END) as total_in,
            SUM(CASE WHEN r.record_type = 2 THEN r.quantity ELSE 0 END) as total_consumed,
            SUM(CASE WHEN r.record_type = 3 THEN r.quantity ELSE 0 END) as total_waste,
            SUM(CASE WHEN r.record_type = 4 AND r.quantity > 0 THEN r.quantity ELSE 0 END) as total_adjust_up,
            SUM(CASE WHEN r.record_type = 4 AND r.quantity < 0 THEN ABS(r.quantity) ELSE 0 END) as total_adjust_down
        FROM inv_record r
        JOIN inv_material m ON r.material_id = m.id
        WHERE DATE(r.create_time) BETWEEN ? AND ?
        GROUP BY r.material_id, m.name, m.unit
        ORDER BY total_consumed DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$filter_start_date, $filter_end_date]);
    $stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存消耗统计失败：' . $e->getMessage();
    $stats = [];
}

// 判断当前显示的表单类型
$form_type = isset($_GET['form']) ? $_GET['form'] : '';

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'waste') {
        $success = '报废记录添加成功！';
    } elseif ($_GET['success'] == 'adjust') {
        $success = '盘点调整记录添加成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存消耗追踪</h2>
            <div class="breadcrumb">
                <a href="index.php">库存管理</a> &gt; 库存消耗追踪
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="tracking.php?form=waste" class="btn btn-danger">添加报废记录</a>
                <a href="tracking.php?form=adjust" class="btn btn-primary">盘点调整</a>
            </div>

            <!-- 添加报废记录表单 -->
            <?php if ($form_type == 'waste'): ?>
                <div class="form-container">
                    <h3>添加报废记录</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="waste">

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id">
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="material_id">原料：</label>
                            <select id="material_id" name="material_id" required>
                                <option value="">请选择原料</option>
                                <?php foreach ($materials as $material): ?>
                                    <option value="<?php echo $material['id']; ?>">
                                        <?php echo htmlspecialchars($material['name']); ?> (当前库存: <?php echo $material['stock']; ?> <?php echo htmlspecialchars($material['unit']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quantity">报废数量：</label>
                            <input type="number" id="quantity" name="quantity" min="0.01" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="reason">报废原因：</label>
                            <textarea id="reason" name="reason" rows="3"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-danger">提交报废</button>
                            <a href="tracking.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 盘点调整表单 -->
            <?php if ($form_type == 'adjust'): ?>
                <div class="form-container">
                    <h3>库存盘点调整</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="adjust">

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id">
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="material_id">原料：</label>
                            <select id="material_id" name="material_id" required>
                                <option value="">请选择原料</option>
                                <?php foreach ($materials as $material): ?>
                                    <option value="<?php echo $material['id']; ?>">
                                        <?php echo htmlspecialchars($material['name']); ?> (当前库存: <?php echo $material['stock']; ?> <?php echo htmlspecialchars($material['unit']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="adjustment_type">调整类型：</label>
                            <select id="adjustment_type" name="adjustment_type">
                                <option value="1">增加</option>
                                <option value="2">减少</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quantity">调整数量：</label>
                            <input type="number" id="quantity" name="quantity" min="0.01" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="reason">调整原因：</label>
                            <textarea id="reason" name="reason" rows="3"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">提交调整</button>
                            <a href="tracking.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 筛选条件 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="material_id">原料：</label>
                            <select id="material_id" name="material_id">
                                <option value="0">全部</option>
                                <?php foreach ($materials as $material): ?>
                                    <option value="<?php echo $material['id']; ?>" <?php echo ($filter_material_id == $material['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($material['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="record_type">记录类型：</label>
                            <select id="record_type" name="record_type">
                                <option value="0" <?php echo ($filter_record_type == 0) ? 'selected' : ''; ?>>全部</option>
                                <option value="1" <?php echo ($filter_record_type == 1) ? 'selected' : ''; ?>>入库</option>
                                <option value="2" <?php echo ($filter_record_type == 2) ? 'selected' : ''; ?>>订单消耗</option>
                                <option value="3" <?php echo ($filter_record_type == 3) ? 'selected' : ''; ?>>报废</option>
                                <option value="4" <?php echo ($filter_record_type == 4) ? 'selected' : ''; ?>>盘点调整</option>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="tracking.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 库存消耗统计 -->
            <div class="table-container">
                <h3>库存消耗统计（<?php echo $filter_start_date; ?> 至 <?php echo $filter_end_date; ?>）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>单位</th>
                            <th>入库数量</th>
                            <th>订单消耗</th>
                            <th>报废数量</th>
                            <th>盘点增加</th>
                            <th>盘点减少</th>
                            <th>净变化</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($stats)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无库存消耗统计数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($stats as $stat): ?>
                                <?php
                                $net_change = $stat['total_in'] - $stat['total_consumed'] - $stat['total_waste'] + $stat['total_adjust_up'] - $stat['total_adjust_down'];
                                ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($stat['material_name']); ?></td>
                                    <td><?php echo htmlspecialchars($stat['unit']); ?></td>
                                    <td><?php echo number_format($stat['total_in'], 2); ?></td>
                                    <td><?php echo number_format($stat['total_consumed'], 2); ?></td>
                                    <td><?php echo number_format($stat['total_waste'], 2); ?></td>
                                    <td><?php echo number_format($stat['total_adjust_up'], 2); ?></td>
                                    <td><?php echo number_format($stat['total_adjust_down'], 2); ?></td>
                                    <td class="<?php echo $net_change >= 0 ? 'status-active' : 'status-inactive'; ?>">
                                        <?php echo number_format($net_change, 2); ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 库存变动记录 -->
            <div class="table-container">
                <h3>库存变动记录（最近100条）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>门店</th>
                            <th>原料</th>
                            <th>记录类型</th>
                            <th>数量</th>
                            <th>关联订单</th>
                            <th>关联采购</th>
                            <th>批次号</th>
                            <th>过期日期</th>
                            <th>操作人</th>
                            <th>记录时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($records)): ?>
                            <tr>
                                <td colspan="11" class="text-center">暂无库存变动记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($records as $record): ?>
                                <tr>
                                    <td><?php echo $record['id']; ?></td>
                                    <td><?php echo htmlspecialchars($record['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($record['material_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($record['record_type'] == 1) echo '<span class="status-active">入库</span>';
                                        elseif ($record['record_type'] == 2) echo '<span class="status-pending">订单消耗</span>';
                                        elseif ($record['record_type'] == 3) echo '<span class="status-inactive">报废</span>';
                                        elseif ($record['record_type'] == 4) {
                                            if ($record['quantity'] > 0) {
                                                echo '<span class="status-active">盘点增加</span>';
                                            } else {
                                                echo '<span class="status-inactive">盘点减少</span>';
                                            }
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        echo number_format(abs($record['quantity']), 2) . ' ' . htmlspecialchars($record['unit']);
                                        if ($record['record_type'] == 4 && $record['quantity'] < 0) {
                                            echo ' (-)';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $record['order_no'] ? htmlspecialchars($record['order_no']) : '-'; ?></td>
                                    <td><?php echo $record['purchase_order_no'] ? htmlspecialchars($record['purchase_order_no']) : '-'; ?></td>
                                    <td><?php echo $record['batch_no'] ? htmlspecialchars($record['batch_no']) : '-'; ?></td>
                                    <td><?php echo $record['expiry_date'] ? date('Y-m-d', strtotime($record['expiry_date'])) : '-'; ?></td>
                                    <td><?php echo htmlspecialchars($record['operator'] ?: '-'); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>