<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('statistics.inventory');

// 记录访问日志
record_log('访问库存周转分析页面');

// 处理库存数据更新请求
if (isset($_POST['update_inventory'])) {
    $update_store_id = isset($_POST['update_store_id']) ? intval($_POST['update_store_id']) : 0;
    $update_year = isset($_POST['update_year']) ? intval($_POST['update_year']) : date('Y');
    $update_month = isset($_POST['update_month']) ? intval($_POST['update_month']) : date('n');

    try {
        // 设置统计周期
        $period = $update_year . '-' . str_pad($update_month, 2, '0', STR_PAD_LEFT);
        $start_date = $period . '-01';
        $end_date = date('Y-m-t', strtotime($start_date));

        // 准备查询条件
        $where_store = $update_store_id > 0 ? "AND im.store_id = " . $update_store_id : "";

        // 获取库存材料数据
        $inventory_sql = "
            SELECT 
                im.id AS material_id,
                im.store_id,
                im.name AS material_name,
                im.category,
                im.stock,
                im.cost_price,
                im.unit,
                (SELECT IFNULL(SUM(CASE WHEN ir.record_type = 2 THEN ir.quantity ELSE 0 END), 0) 
                 FROM inv_record ir 
                 WHERE ir.material_id = im.id 
                 AND ir.create_time BETWEEN ? AND ?) AS out_quantity,
                (SELECT IFNULL(SUM(CASE WHEN ir.record_type = 1 THEN ir.quantity ELSE 0 END), 0) 
                 FROM inv_record ir 
                 WHERE ir.material_id = im.id 
                 AND ir.create_time BETWEEN ? AND ?) AS in_quantity
            FROM 
                inv_material im
            WHERE 
                im.status = 1
                $where_store
        ";

        $stmt = $pdo->prepare($inventory_sql);
        $stmt->execute([
            $start_date . ' 00:00:00',
            $end_date . ' 23:59:59',
            $start_date . ' 00:00:00',
            $end_date . ' 23:59:59'
        ]);

        $inventory_data = $stmt->fetchAll();

        $updated_count = 0;

        // 更新或插入库存报表数据
        foreach ($inventory_data as $item) {
            // 获取期初库存（月初库存 = 当前库存 - 入库 + 出库）
            $begin_stock = $item['stock'] - $item['in_quantity'] + $item['out_quantity'];

            // 计算期末库存（就是当前库存）
            $end_stock = $item['stock'];

            // 计算消耗率（日均消耗量/期末库存）
            $days_in_month = date('t', strtotime($start_date));
            $daily_consumption = $days_in_month > 0 ? $item['out_quantity'] / $days_in_month : 0;
            $consumption_rate = $end_stock > 0 && $daily_consumption > 0 ? $daily_consumption / $end_stock : 0;

            // 计算周转天数（当前库存/日均消耗量）
            // 设置最大值为999天，避免数值超出范围
            if ($daily_consumption > 0) {
                $turnover_days = min(999, $end_stock / $daily_consumption);
            } else {
                $turnover_days = 999; // 如果没有消耗，设置为最大值
            }

            // 检查是否已存在该材料该周期的库存记录
            $check_sql = "
                SELECT id FROM rpt_inventory 
                WHERE store_id = ? AND material_id = ? AND period = ?
            ";
            $check_stmt = $pdo->prepare($check_sql);
            $check_stmt->execute([$item['store_id'], $item['material_id'], $period]);
            $exists = $check_stmt->fetch();

            if ($exists) {
                // 更新现有记录
                $update_sql = "
                    UPDATE rpt_inventory SET
                        material_name = ?,
                        begin_stock = ?,
                        end_stock = ?,
                        in_qty = ?,
                        out_qty = ?,
                        turnover_days = ?,
                        consumption_rate = ?
                    WHERE id = ?
                ";
                $update_stmt = $pdo->prepare($update_sql);
                $update_stmt->execute([
                    $item['material_name'],
                    $begin_stock,
                    $end_stock,
                    $item['in_quantity'],
                    $item['out_quantity'],
                    $turnover_days,
                    $consumption_rate,
                    $exists['id']
                ]);
            } else {
                // 添加新记录
                $insert_sql = "
                    INSERT INTO rpt_inventory (
                        store_id, material_id, material_name, period,
                        begin_stock, end_stock, in_qty, out_qty,
                        turnover_days, consumption_rate
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ";
                $insert_stmt = $pdo->prepare($insert_sql);
                $insert_stmt->execute([
                    $item['store_id'],
                    $item['material_id'],
                    $item['material_name'],
                    $period,
                    $begin_stock,
                    $end_stock,
                    $item['in_quantity'],
                    $item['out_quantity'],
                    $turnover_days,
                    $consumption_rate
                ]);
            }

            $updated_count++;
        }

        $success = "成功更新{$updated_count}条库存数据";
        record_log("更新{$period}期间的库存统计数据");
    } catch (PDOException $e) {
        $error = '更新库存数据失败：' . $e->getMessage();
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_category = isset($_GET['category']) ? trim($_GET['category']) : '';
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : ''; // 默认显示全部
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : ''; // 默认显示全部
$filter_sort = isset($_GET['sort']) ? trim($_GET['sort']) : 'turnover'; // 默认按周转天数排序
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : -1; // -1表示全部

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有原料类别，用于下拉选择
try {
    $stmt = $pdo->query("SELECT DISTINCT category FROM inv_material ORDER BY category");
    $categories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取原料类别失败：' . $e->getMessage();
    $categories = [];
}

// 构建查询条件
$where = [];
$params = [];

// 当前日期和月份处理
$current_date = date('Y-m-d');
$current_month = date('Y-m');

if ($filter_store_id > 0) {
    $where[] = "im.store_id = ?";
    $params[] = $filter_store_id;
}

if (!empty($filter_category)) {
    $where[] = "im.category = ?";
    $params[] = $filter_category;
}

if ($filter_status >= 0) {
    $where[] = "im.status = ?";
    $params[] = $filter_status;
}

// 获取原料库存和周转数据
try {
    $sql = "
        SELECT 
            im.id AS material_id,
            im.name AS material_name,
            im.category,
            im.unit,
            im.stock AS current_stock,
            im.min_stock,
            im.cost_price,
            s.store_name,
            im.status,
            (
                SELECT SUM(ir.quantity)
                FROM inv_record ir
                WHERE ir.material_id = im.id
                AND ir.store_id = im.store_id
                AND ir.record_type = 2
                " . (!empty($filter_start_date) ? "AND ir.create_time >= '" . $filter_start_date . " 00:00:00'" : "") . "
                " . (!empty($filter_end_date) ? "AND ir.create_time <= '" . $filter_end_date . " 23:59:59'" : "") . "
            ) AS consumption_qty,
            (
                SELECT SUM(ir.quantity)
                FROM inv_record ir
                WHERE ir.material_id = im.id
                AND ir.store_id = im.store_id
                AND ir.record_type = 1
                " . (!empty($filter_start_date) ? "AND ir.create_time >= '" . $filter_start_date . " 00:00:00'" : "") . "
                " . (!empty($filter_end_date) ? "AND ir.create_time <= '" . $filter_end_date . " 23:59:59'" : "") . "
            ) AS incoming_qty,
            (
                SELECT AVG(ri.consumption_rate)
                FROM rpt_inventory ri
                WHERE ri.material_id = im.id
                AND ri.store_id = im.store_id
                " . (!empty($filter_start_date) ? "AND ri.period >= '" . substr($filter_start_date, 0, 7) . "'" : "") . "
                " . (!empty($filter_end_date) ? "AND ri.period <= '" . substr($filter_end_date, 0, 7) . "'" : "") . "
            ) AS avg_consumption_rate,
            (
                SELECT AVG(ri.turnover_days)
                FROM rpt_inventory ri
                WHERE ri.material_id = im.id
                AND ri.store_id = im.store_id
                " . (!empty($filter_start_date) ? "AND ri.period >= '" . substr($filter_start_date, 0, 7) . "'" : "") . "
                " . (!empty($filter_end_date) ? "AND ri.period <= '" . substr($filter_end_date, 0, 7) . "'" : "") . "
            ) AS avg_turnover_days
        FROM 
            inv_material im
            JOIN store_info s ON im.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY ";

    // 排序方式
    if ($filter_sort == 'consumption') {
        $sql .= " avg_consumption_rate DESC";
    } else {
        $sql .= " avg_turnover_days DESC";
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $inventory_data = $stmt->fetchAll();

    // 计算总库存价值和库存状态
    $total_inventory_value = 0;
    $low_stock_count = 0;
    $normal_stock_count = 0;
    $excess_stock_count = 0;

    foreach ($inventory_data as &$item) {
        // 消耗天数（库存可供消耗的天数）
        $item['avg_consumption_rate'] = floatval($item['avg_consumption_rate']);
        if ($item['avg_consumption_rate'] > 0) {
            $item['consumption_days'] = round($item['current_stock'] / $item['avg_consumption_rate']);
        } else {
            $item['consumption_days'] = 999; // 表示无限天数
        }

        // 库存状态
        if ($item['current_stock'] <= $item['min_stock']) {
            $item['stock_status'] = 1; // 库存不足
            $low_stock_count++;
        } elseif ($item['current_stock'] <= $item['min_stock'] * 2) {
            $item['stock_status'] = 2; // 库存正常
            $normal_stock_count++;
        } else {
            $item['stock_status'] = 3; // 库存过剩
            $excess_stock_count++;
        }

        // 计算库存价值
        $item['stock_value'] = $item['current_stock'] * $item['cost_price'];
        $total_inventory_value += $item['stock_value'];

        // 计算建议补货数量
        if ($item['stock_status'] == 1) {
            // 库存不足，建议补货到安全库存的2倍
            $item['suggested_purchase'] = ($item['min_stock'] * 2) - $item['current_stock'];
        } elseif ($item['stock_status'] == 2 && $item['consumption_days'] < 30) {
            // 库存正常但消耗快，建议补货到30天的用量
            $item['suggested_purchase'] = ($item['avg_consumption_rate'] * 30) - $item['current_stock'];
            $item['suggested_purchase'] = max(0, $item['suggested_purchase']);
        } else {
            $item['suggested_purchase'] = 0;
        }

        // 预计耗尽日期
        if ($item['avg_consumption_rate'] > 0) {
            $days_to_empty = $item['current_stock'] / $item['avg_consumption_rate'];
            $item['empty_date'] = date('Y-m-d', strtotime("+{$days_to_empty} days"));
        } else {
            $item['empty_date'] = '无法预计';
        }
    }
} catch (PDOException $e) {
    $error = '获取库存数据失败：' . $e->getMessage();
    $inventory_data = [];
    $total_inventory_value = 0;
    $low_stock_count = 0;
    $normal_stock_count = 0;
    $excess_stock_count = 0;
}

// 获取月度消耗趋势
try {
    $trend_params = $params;
    $months_limit = 6; // 显示最近6个月的数据

    $trend_sql = "
        SELECT 
            ri.period,
            SUM(ri.out_qty) AS total_consumption,
            AVG(ri.consumption_rate) AS avg_consumption_rate
        FROM 
            rpt_inventory ri
            JOIN inv_material im ON ri.material_id = im.id
    ";

    $trend_where = $where;
    if (!empty($trend_where)) {
        $trend_sql .= " WHERE " . implode(' AND ', $trend_where);
    } else {
        $trend_sql .= " WHERE 1=1";
    }

    $trend_sql .= " 
        GROUP BY 
            ri.period
        ORDER BY 
            ri.period DESC
        LIMIT " . intval($months_limit);

    $stmt = $pdo->prepare($trend_sql);
    $stmt->execute($trend_params);
    $monthly_trend = $stmt->fetchAll();
    $monthly_trend = array_reverse($monthly_trend); // 反转数组以按时间正序显示
} catch (PDOException $e) {
    $error = '获取月度消耗趋势数据失败：' . $e->getMessage();
    $monthly_trend = [];
}

// 获取原料入库记录
try {
    $incoming_params = $params;

    $incoming_sql = "
        SELECT 
            ir.material_id,
            im.name AS material_name,
            ir.batch_no,
            ir.expiry_date,
            ir.quantity,
            ir.create_time,
            po.order_no AS purchase_order,
            po.price AS unit_price,
            (ir.quantity * po.price) AS total_price,
            ir.operator
        FROM 
            inv_record ir
            JOIN inv_material im ON ir.material_id = im.id
            LEFT JOIN pur_order po ON ir.purchase_id = po.id
        WHERE 
            ir.record_type = 1
    ";

    $incoming_where = $where;
    if (!empty($incoming_where)) {
        // 将im. 改为 ir.
        $incoming_where = str_replace('im.store_id', 'ir.store_id', $incoming_where);
        $incoming_sql .= " AND " . implode(' AND ', $incoming_where);
    }

    if (!empty($filter_start_date)) {
        $incoming_sql .= " AND ir.create_time >= ?";
        $incoming_params[] = $filter_start_date . ' 00:00:00';
    }

    if (!empty($filter_end_date)) {
        $incoming_sql .= " AND ir.create_time <= ?";
        $incoming_params[] = $filter_end_date . ' 23:59:59';
    }

    $incoming_sql .= " ORDER BY ir.create_time DESC LIMIT 20";

    $stmt = $pdo->prepare($incoming_sql);
    $stmt->execute($incoming_params);
    $incoming_records = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取入库记录失败：' . $e->getMessage();
    $incoming_records = [];
}

// 获取即将过期的原料
try {
    $expiry_params = $params;

    $expiry_sql = "
        SELECT 
            ir.material_id,
            im.name AS material_name,
            im.category,
            s.store_name,
            ir.batch_no,
            ir.expiry_date,
            ir.quantity,
            ir.create_time,
            DATEDIFF(ir.expiry_date, CURRENT_DATE) AS days_to_expiry
        FROM 
            inv_record ir
            JOIN inv_material im ON ir.material_id = im.id
            JOIN store_info s ON ir.store_id = s.id
        WHERE 
            ir.record_type = 1
            AND ir.expiry_date IS NOT NULL
            AND ir.expiry_date > CURRENT_DATE
            AND DATEDIFF(ir.expiry_date, CURRENT_DATE) <= 30
    ";

    $expiry_where = $where;
    if (!empty($expiry_where)) {
        // 将im. 改为 ir.
        $expiry_where = str_replace('im.store_id', 'ir.store_id', $expiry_where);
        $expiry_sql .= " AND " . implode(' AND ', $expiry_where);
    }

    $expiry_sql .= " ORDER BY days_to_expiry ASC LIMIT 10";

    $stmt = $pdo->prepare($expiry_sql);
    $stmt->execute($expiry_params);
    $expiring_materials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取即将过期原料失败：' . $e->getMessage();
    $expiring_materials = [];
}

// 获取库存状态名称
function getStockStatusName($status)
{
    switch ($status) {
        case 1:
            return '库存不足';
        case 2:
            return '库存正常';
        case 3:
            return '库存过剩';
        default:
            return '未知状态';
    }
}

// 获取原料状态名称
function getMaterialStatusName($status)
{
    switch ($status) {
        case 1:
            return '正常';
        case 0:
            return '停用';
        default:
            return '未知';
    }
}

?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存周转分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 库存周转分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 更新库存数据表单 -->
            <div class="form-container">
                <h3>更新库存数据</h3>
                <form method="post" action="">
                    <div class="form-row">
                        <div class="filter-item">
                            <label for="update_store_id">门店：</label>
                            <select id="update_store_id" name="update_store_id">
                                <option value="0">所有门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_year">年份：</label>
                            <select id="update_year" name="update_year">
                                <?php
                                $current_year = date('Y');
                                for ($y = $current_year; $y >= 2020; $y--):
                                ?>
                                    <option value="<?php echo $y; ?>"><?php echo $y; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_month">月份：</label>
                            <select id="update_month" name="update_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo (intval(date('n')) == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" name="update_inventory" value="1" class="btn btn-success">更新库存数据</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="category">原料类别：</label>
                            <select id="category" name="category">
                                <option value="">全部类别</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['category']; ?>" <?php echo ($filter_category == $category['category']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($category['category']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="sort">排序方式：</label>
                            <select id="sort" name="sort">
                                <option value="turnover" <?php echo ($filter_sort == 'turnover') ? 'selected' : ''; ?>>按周转天数排序</option>
                                <option value="consumption" <?php echo ($filter_sort == 'consumption') ? 'selected' : ''; ?>>按消耗率排序</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="-1">全部</option>
                                <option value="1" <?php echo ($filter_status == 1) ? 'selected' : ''; ?>>正常</option>
                                <option value="0" <?php echo ($filter_status == 0) ? 'selected' : ''; ?>>停用</option>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">查询</button>
                            <a href="inventory.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 库存统计摘要 -->
            <div class="info-box">
                <h3>库存统计摘要（<?php echo empty($filter_start_date) && empty($filter_end_date) ? '全部数据' : $filter_start_date . ' 至 ' . $filter_end_date; ?>）</h3>
                <ul>
                    <li>总库存价值：￥<?php echo number_format($total_inventory_value, 2); ?></li>
                    <li>库存不足原料：<?php echo $low_stock_count; ?> 种</li>
                    <li>库存正常原料：<?php echo $normal_stock_count; ?> 种</li>
                    <li>库存过剩原料：<?php echo $excess_stock_count; ?> 种</li>
                </ul>
            </div>

            <!-- 库存状态列表 -->
            <div class="table-container">
                <h3>原料库存周转状况（<?php echo $filter_sort == 'turnover' ? '按周转天数' : '按消耗率'; ?>）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>类别</th>
                            <th>门店</th>
                            <th>当前库存</th>
                            <th>最低库存</th>
                            <th>库存状态</th>
                            <th>日均消耗</th>
                            <th>平均周转天数</th>
                            <th>预计耗尽日期</th>
                            <th>库存价值</th>
                            <th>建议补货</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($inventory_data)): ?>
                            <tr>
                                <td colspan="11" class="text-center">暂无库存数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($inventory_data as $item): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($item['material_name']); ?></td>
                                    <td><?php echo htmlspecialchars($item['category']); ?></td>
                                    <td><?php echo htmlspecialchars($item['store_name']); ?></td>
                                    <td><?php echo number_format($item['current_stock'], 2) . ' ' . $item['unit']; ?></td>
                                    <td><?php echo number_format($item['min_stock'], 2) . ' ' . $item['unit']; ?></td>
                                    <td><?php echo getStockStatusName($item['stock_status']); ?></td>
                                    <td><?php echo number_format($item['avg_consumption_rate'], 2) . ' ' . $item['unit']; ?></td>
                                    <td><?php echo number_format($item['avg_turnover_days'], 1); ?> 天</td>
                                    <td><?php echo $item['empty_date']; ?></td>
                                    <td>￥<?php echo number_format($item['stock_value'], 2); ?></td>
                                    <td><?php echo $item['suggested_purchase'] > 0 ? number_format($item['suggested_purchase'], 2) . ' ' . $item['unit'] : '无需补货'; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 月度消耗趋势 -->
            <div class="table-container">
                <h3>月度消耗趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>总消耗量</th>
                            <th>平均日消耗率</th>
                            <th>消耗变化</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_trend)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无消耗趋势数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $prev_consumption = null;
                            foreach ($monthly_trend as $month):
                                $change_pct = null;
                                if ($prev_consumption !== null && $prev_consumption > 0) {
                                    $change_pct = (($month['total_consumption'] - $prev_consumption) / $prev_consumption) * 100;
                                }
                                $prev_consumption = $month['total_consumption'];
                            ?>
                                <tr>
                                    <td><?php echo $month['period']; ?></td>
                                    <td><?php echo number_format($month['total_consumption'], 2); ?></td>
                                    <td><?php echo number_format($month['avg_consumption_rate'], 2); ?></td>
                                    <td>
                                        <?php if ($change_pct !== null): ?>
                                            <?php echo number_format($change_pct, 2); ?>%
                                            <?php if ($change_pct > 0): ?>
                                                <span style="color: #e74c3c;">↑</span>
                                            <?php elseif ($change_pct < 0): ?>
                                                <span style="color: #2ecc71;">↓</span>
                                            <?php else: ?>
                                                -
                                            <?php endif; ?>
                                        <?php else: ?>
                                            -
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近入库记录 -->
            <div class="table-container">
                <h3>最近入库记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>批次号</th>
                            <th>入库数量</th>
                            <th>单价</th>
                            <th>金额</th>
                            <th>采购单号</th>
                            <th>过期日期</th>
                            <th>入库时间</th>
                            <th>操作人</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($incoming_records)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无入库记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($incoming_records as $record): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($record['material_name']); ?></td>
                                    <td><?php echo htmlspecialchars($record['batch_no'] ?? '无批次'); ?></td>
                                    <td><?php echo number_format($record['quantity'], 2); ?></td>
                                    <td><?php echo isset($record['unit_price']) ? '￥' . number_format($record['unit_price'], 2) : '-'; ?></td>
                                    <td><?php echo isset($record['total_price']) ? '￥' . number_format($record['total_price'], 2) : '-'; ?></td>
                                    <td><?php echo htmlspecialchars($record['purchase_order'] ?? ''); ?></td>
                                    <td><?php echo $record['expiry_date'] ?? '无过期日期'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                    <td><?php echo htmlspecialchars($record['operator']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 即将过期原料 -->
            <div class="table-container">
                <h3>即将过期原料提醒</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>类别</th>
                            <th>门店</th>
                            <th>批次号</th>
                            <th>数量</th>
                            <th>过期日期</th>
                            <th>剩余天数</th>
                            <th>入库时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($expiring_materials)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无即将过期的原料</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($expiring_materials as $material): ?>
                                <tr<?php echo $material['days_to_expiry'] <= 7 ? ' style="background-color: #ffdddd;"' : ''; ?>>
                                    <td><?php echo htmlspecialchars($material['material_name']); ?></td>
                                    <td><?php echo htmlspecialchars($material['category']); ?></td>
                                    <td><?php echo htmlspecialchars($material['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($material['batch_no'] ?? '无批次'); ?></td>
                                    <td><?php echo number_format($material['quantity'], 2); ?></td>
                                    <td><?php echo $material['expiry_date']; ?></td>
                                    <td><?php echo $material['days_to_expiry']; ?> 天</td>
                                    <td><?php echo date('Y-m-d', strtotime($material['create_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>